"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var access_control_authorization_1 = require("./access-control.authorization");
describe('[Access Control]', function () {
    var accessControll;
    var newVideo, myVideo, videoFromThirdPary, adminUser, normalUser, organizationManager, guestUser;
    var queryMock;
    accessControll = new access_control_authorization_1.CrudAccessControl('video', [
        { role: 'guest', resource: 'catalog', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'create:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'update:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'delete:any', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'create:own', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'update:own', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'delete:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'create:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'update:own', attributes: ['*'] },
        { role: '$organization:manager', resource: 'video', action: 'delete:own', attributes: ['*'] }
    ]);
    adminUser = {
        _id: '001',
        roles: ['admin']
    };
    organizationManager = {
        _id: '001',
        roles: ['user'],
        organization: {
            ref: { code: 'vert' },
            role: 'manager'
        }
    };
    normalUser = {
        _id: '100',
        roles: ['user']
    };
    guestUser = {
        _id: '200',
        roles: ['guest']
    };
    newVideo = {
        title: 'Star Wars Episode IX',
    };
    myVideo = {
        title: 'Fight Club',
        owner: { userId: "001" }
    };
    videoFromThirdPary = {
        title: 'The Godfather',
        owner: { userId: "301" }
    };
    queryMock = {
        where: { or: function () { } }
    };
    it('admin should be allowed to create video for any', function () {
        var permission = accessControll.check(adminUser, 'read');
        chai_1.expect(permission.granted).to.equal(true);
        chai_1.expect(permission.for).to.equal('user');
        chai_1.expect(permission.type).to.equal('any');
    });
    it('user should be allowed to create video of its own', function () {
        var permission = accessControll.check(normalUser, 'create');
        chai_1.expect(permission.granted).to.equal(true);
        chai_1.expect(permission.for).to.equal('user');
        chai_1.expect(permission.type).to.equal('own');
    });
    //
    it('guest should not be allowed to create video', function () {
        var permission = accessControll.check(guestUser, 'create');
        chai_1.expect(permission.granted).to.equal(false);
    });
    //
    it('admin should be allowed to update any video', function () {
        var permission = accessControll.check(adminUser, 'update');
        chai_1.expect(permission.granted).to.equal(true);
    });
});
